fnss.adapters.autonetkit.from_autonetkit — FNSS 0.5.0 documentation

### Navigation

- index
- modules |
- modules |
- next |
- previous |
- FNSS 0.5.0 documentation »
- API Reference »
- Functions »

# fnss.adapters.autonetkit.from_autonetkit

`from_autonetkit`(topology)

  Convert an AutoNetKit graph into an FNSS Topology object.

  The current implementation of this function only renames the weight attribute from weight to ospf_cost

  Parameters : | topology : NetworkX graph An AutoNetKit NetworkX graph
  Returns : | fnss_topology : FNSS Topology FNSS topology

### Navigation

- index
- modules |
- modules |
- next |
- previous |
- FNSS 0.5.0 documentation »
- API Reference »
- Functions »